//+------------------------------------------------------------------+
//|                                                 BridgeQuotes.mqh |
//|                                                  Denis Lubentsov |
//+------------------------------------------------------------------+
#property copyright "Denis Lubentsov"

// {{ Used for login to Quotes Server (see _Login() function)
extern string QuotesServerAddress;
extern int Port;
extern string Login;
extern string Password;
// Used for login to Quotes Server (see _Login() function) }}

string FXSymbol;   // Symbol name in "CCY1/CCY2" format
int SizeBids[1], SizeAsks[1];
int Size = 5;      // Considering required Quotes Depth is 5
double Bids[5];    // Contains Bids after successful call to _GetLastQuotes() or _GetLastNQuotes()
double Asks[5];    // Contains Asks after successful call to _GetLastQuotes() or _GetLastNQuotes()
double BidVols[5]; // Contains Bid Volumes after successful call to _GetLastQuotes() or _GetLastNQuotes()
double AskVols[5]; // Contains Ask Volumes after successful call to _GetLastQuotes() or _GetLastNQuotes()
string LastError;  // Contains description of Last Error, can be obtained via _GetLastError()

//+------------------------------------------------------------------+
//| expert helper functions                                          |
//+------------------------------------------------------------------+
bool _Login()
{
   bool bRes = false;
   int nRes = Login(QuotesServerAddress, Port, Login, Password);
   if (-2 == nRes)
      LastError = "Login(): Insufficient system resources - Unable to spawn Quotes thread!";
   else if (-1 == nRes)
      LastError = "Login(): Unable to login to Quotes Server (" + QuotesServerAddress + ":" + Port + ")!";
   else if (0 == nRes)
   {
      bRes = true;
      LastError = "Login(): Already logged on to Quotes Server (" + QuotesServerAddress + ":" + Port + ")!";
   }
   else if (1 == nRes)
   {
      bRes = true;
      LastError = "Login(): Successfully logged on to Quotes Server (" + QuotesServerAddress + ":" + Port + ")!";
   }
   else
      LastError = "Login(): Unknown result!";   
   return (bRes);
}

bool _Logoff()
{
   bool bRes = true;
   int nRes = Logoff();
   if (0 == nRes)
      LastError = "Logoff(): Already logged off!";
   else if (1 == nRes)
      LastError = "Logoff(): Successfully logged off!";
   else
   {
      bRes = false;
      LastError = "Logoff(): Unknown result!";
   }
   return (bRes);
}

bool _GetLastQuotes()
{
   bool bRes = false;
   int nRes = GetLastQuotes(FXSymbol, SizeBids, Bids, BidVols, SizeAsks, Asks, AskVols);
   if (-2 == nRes)
      LastError = "GetLastQuotes(): Logged off from Quotes Server!";
   else if (-1 == nRes)
      LastError = "GetLastQuotes(): Incorrect parameters!";
   else if (0 == nRes)
   {
      bRes = true;
      LastError = "GetLastQuotes(): No Quotes for " + FXSymbol + "!";
   }
   else
   {
      bRes = true;
      LastError = "";
   }
   return (bRes);
}

bool _GetLastNQuotes()
{
   bool bRes = false;
   int nRes = GetLastNQuotes(FXSymbol, Size, Bids, BidVols, Asks, AskVols);
   if (-2 == nRes)
      LastError = "GetLastQuotes(): Logged off from Quotes Server!";
   else if (-1 == nRes)
      LastError = "GetLastQuotes(): Incorrect parameters!";
   else if (0 == nRes)
   {
      bRes = true;
      LastError = "GetLastQuotes(): No Quotes for " + FXSymbol + "!";
   }
   else
   {
      bRes = true;
      LastError = "";
   }
   return (bRes);
}

string _GetLastError()
{
   return (LastError);
}

